# nt-bot.v2

Перед установкой настраиваем питон, запустив следующие команды под правами админа:
```
  python -m ensurepip
  python -m pip install --upgrade pip
```

Далее идём в нужный путь, куда будем ставить бота
```
    cd %НУЖНЫЙ ПУТЬ%
```

Далее команды в cmd:
```
git clone https://github.com/Bikbai/nt-bot.v2.git
cd nt-bot.v2
.\run.cmd
```

При старте спросит значение секретного токена бота, который можно на машине прописать в переменную окружения BOT_TOKEN. Оный токен бот сохранит себе для следующих запусков в .\data\token.key

Последующие запуски - запуск run.cmd
